<?php
// wbb imports
require_once(WBB_DIR.'lib/data/board/Board.class.php');
require_once(WBB_DIR.'lib/data/thread/ViewableThread.class.php');
require_once(WBB_DIR.'lib/data/thread/ThreadList.class.php');
require_once(WBB_DIR.'lib/data/boxes/PortalBox.class.php');
require_once(WBB_DIR.'lib/data/boxes/StandardPortalBox.class.php');

/**
 * This box shows the latest threads and posts
 *
 * @package	com.woltlab.community.portal.lastthreads
 * @author	Ronny Lau, Alexander Ebert, Martin Schwendowius
 * @copyright	2009- 2010 WoltLab Community, wbbaddons.de
 * @license	GNU Lesser Public License <http://www.gnu.org/licenses/lgpl.html>
 * @subpackage	data.boxes
 * @category	Portal
 */
class LastThreadsBox extends PortalBox implements StandardPortalBox {
	public $stylesheet = 'lastthreads';
	public $lastThreadList = array();
	public $dataRead = false;

	/**
	 * Fetch all threads with new posts within
	 *
	 * @access	public
	 * @param	array	$data		Ignored
	 * @param	string	$boxname	Boxname
	 * @return	void
	 */
	public function readData() {
		if ($this->dataRead == true) return;
		else $this->dataRead = true;
		$boardIDs = Board::getAccessibleBoardIDArray();
		
		//skip ignored boards
		$ignoredBoards = array();
		$sql = "SELECT boardID FROM wbb".WBB_N."_board_ignored_by_user WHERE userID = ".WCF::getUser()->userID;
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$ignoredBoards[] = $row['boardID'];
		}
				
		$boardIDs = array_diff($boardIDs, $ignoredBoards);

		// No boards are visible to viewer, no action required
		if (empty($boardIDs)) return;

		// determine if any more boards are hidden by configuration
		if (LASTTHREADSBOX_SKIP_BOARDIDS != '') {
			$skipBoardIDs = LASTTHREADSBOX_SKIP_BOARDIDS;
			$boardIDs = array_diff($boardIDs, explode(',', $skipBoardIDs));
			if (empty($boardIDs)) return;
		}
		$sql = "SELECT		last_post.boardID
			FROM 		wbb".WBB_N."_board_last_post last_post
			LEFT JOIN	wbb".WBB_N."_thread thread
			ON		(thread.threadID = last_post.threadID)
			WHERE		last_post.boardID IN (".implode(',', $boardIDs).")
					AND thread.isDisabled = 0
					AND thread.isDeleted = 0
					AND thread.movedThreadID = 0
			ORDER BY	thread.lastPostTime DESC";
		$result = WCF::getDB()->sendQuery($sql, LASTTHREADSBOX_TIME);
		$boardIDs = array();
		while ($row = WCF::getDB()->fetchArray($result)) {
			$boardIDs[] = $row['boardID'];
		}

		if (empty($boardIDs)) return;

		$threadList = new ThreadList();
		$threadList->limit = LASTTHREADSBOX_TIME;
		$threadList->sqlConditions = 'thread.boardID IN('.implode(',', $boardIDs).')
						AND thread.isDeleted = 0
						AND thread.isDisabled = 0
						AND thread.movedThreadID = 0';
		$threadList->sqlSelects .= " board.title as title, board.enableMarkingAsDone as enableMarkingAsDone, thread.time as startTime, ";
		$threadList->sqlJoins .= "LEFT JOIN	wbb".WBB_N."_board board
						ON (board.boardID = thread.boardID)";
		// sort resulsts by posttime
		if (LASTTHREADSBOX_SORT == 'posttime') {
			$threadList->sqlOrderBy	= "thread.lastPostTime DESC, thread.time DESC";
		}
		else {
			$threadList->sqlOrderBy	= "thread.time DESC";
		}


		$threadList->readThreads();


		foreach ($threadList->threads as $key => $thread) {
			$thread->title = WCF::getLanguage()->get($thread->title);
			$tmp = StringUtil::length($thread->topic);

			// truncate topic if necessary
			if (LASTTHREADSBOX_THREADCUT_ACTIVE && ($tmp > LASTTHREADSBOX_THREADCUT_ITEMS)) {
				// substract prefix if set
				$tmp = (!empty($thread->prefix)) ? (LASTTHREADSBOX_THREADCUT_ITEMS - StringUtil::length($thread->prefix)) : LASTTHREADSBOX_THREADCUT_ITEMS;

				$thread->topic	= StringUtil::substring($thread->topic, 0, $tmp) . " [...]";
			}

			// truncate title if necessary
			if (LASTTHREADSBOX_BOARDCUT_ACTIVE && (StringUtil::length($thread->title) > LASTTHREADSBOX_BOARDCUT_ITEMS)) {
				$thread->title = StringUtil::substring($thread->title, 0, LASTTHREADSBOX_BOARDCUT_ITEMS) . " [...]";
			}
			$thread->canReadThread = WCF::getUser()->getBoardPermission('canReadThread', $thread->boardID);
			
			$this->lastThreadList[] = $thread;
		}

		//reset threadList
		$threadList->threads = array();

        }

	/**
	 * @see StandardPortalBox::getTemplateName()
	 */
	public function getTemplateName() {
		return 'lastthreads';
	}
}
?>